[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [42458] branches/soc-2011-tomato: Merging r42442 through r42457 from trunk into soc-2011-tomato

Sergey Sharybin sergey.vfx at gmail.com
Tue Dec 6 10:27:20 CET 2011


Revision: 42458
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=42458
Author:   nazgul
Date:     2011-12-06 09:27:18 +0000 (Tue, 06 Dec 2011)
Log Message:
-----------
Merging r42442 through r42457 from trunk into soc-2011-tomato

Revision Links:
--------------
    http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=42442
    http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=42457

Modified Paths:
--------------
    branches/soc-2011-tomato/build_files/cmake/cmake_qtcreator_project.py
    branches/soc-2011-tomato/intern/cycles/blender/addon/ui.py
    branches/soc-2011-tomato/intern/cycles/blender/blender_sync.cpp
    branches/soc-2011-tomato/intern/cycles/util/util_md5.cpp
    branches/soc-2011-tomato/release/scripts/modules/bpy_extras/io_utils.py
    branches/soc-2011-tomato/release/scripts/startup/bl_operators/object_randomize_transform.py
    branches/soc-2011-tomato/release/scripts/startup/bl_ui/properties_render.py
    branches/soc-2011-tomato/release/scripts/startup/bl_ui/properties_texture.py
    branches/soc-2011-tomato/release/scripts/startup/bl_ui/space_clip.py
    branches/soc-2011-tomato/source/blender/editors/interface/interface_handlers.c
    branches/soc-2011-tomato/source/blender/editors/screen/screendump.c
    branches/soc-2011-tomato/source/blender/editors/space_view3d/drawobject.c

Property Changed:
----------------
    branches/soc-2011-tomato/
    branches/soc-2011-tomato/source/blender/editors/space_outliner/


Property changes on: branches/soc-2011-tomato
___________________________________________________________________
Modified: svn:mergeinfo
   - /branches/soc-2011-cucumber:37517
/branches/vgroup_modifiers:38694-39989
/trunk/blender:36831-42441
   + /branches/soc-2011-cucumber:37517
/branches/vgroup_modifiers:38694-39989
/trunk/blender:36831-42457

Modified: branches/soc-2011-tomato/build_files/cmake/cmake_qtcreator_project.py
===================================================================
--- branches/soc-2011-tomato/build_files/cmake/cmake_qtcreator_project.py	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/build_files/cmake/cmake_qtcreator_project.py	2011-12-06 09:27:18 UTC (rev 42458)
@@ -47,6 +47,13 @@
 import sys
 
 
+def quote_define(define):
+    if " " in define.strip():
+        return '"%s"' % define
+    else:
+        return define
+
+
 def create_qtc_project_main():
     files = list(source_list(SOURCE_DIR, filename_check=is_project_file))
     files_rel = [os.path.relpath(f, start=PROJECT_DIR) for f in files]
@@ -99,7 +106,7 @@
         qtc_cfg = os.path.join(PROJECT_DIR, "%s.config" % FILE_NAME)
         f = open(qtc_cfg, 'w')
         f.write("// ADD PREDEFINED MACROS HERE!\n")
-        defines_final = [("#define %s %s" % item) for item in defines]
+        defines_final = [("#define %s %s" % (item[0], quote_define(item[1]))) for item in defines]
         if sys.platform != "win32":
             defines_final += cmake_compiler_defines()
         f.write("\n".join(defines_final))

Modified: branches/soc-2011-tomato/intern/cycles/blender/addon/ui.py
===================================================================
--- branches/soc-2011-tomato/intern/cycles/blender/addon/ui.py	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/intern/cycles/blender/addon/ui.py	2011-12-06 09:27:18 UTC (rev 42458)
@@ -725,6 +725,7 @@
         if experimental and cscene.device == 'CPU' and engine.with_osl():
             layout.prop(cscene, "shading_system")
 
+
 def draw_pause(self, context):
     layout = self.layout
     scene = context.scene

Modified: branches/soc-2011-tomato/intern/cycles/blender/blender_sync.cpp
===================================================================
--- branches/soc-2011-tomato/intern/cycles/blender/blender_sync.cpp	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/intern/cycles/blender/blender_sync.cpp	2011-12-06 09:27:18 UTC (rev 42458)
@@ -264,7 +264,12 @@
 
 	if(RNA_enum_get(&cscene, "device") != 0) {
 		vector<DeviceType> types = Device::available_types();
-		DeviceType dtype = (RNA_enum_get(&cscene, "gpu_type") == 0)? DEVICE_CUDA: DEVICE_OPENCL;
+		DeviceType dtype;
+		
+		if(!experimental || RNA_enum_get(&cscene, "gpu_type") == 0)
+			dtype = DEVICE_CUDA;
+		else
+			dtype = DEVICE_CUDA;
 
 		if(device_type_available(types, dtype))
 			params.device_type = dtype;

Modified: branches/soc-2011-tomato/intern/cycles/util/util_md5.cpp
===================================================================
--- branches/soc-2011-tomato/intern/cycles/util/util_md5.cpp	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/intern/cycles/util/util_md5.cpp	2011-12-06 09:27:18 UTC (rev 42458)
@@ -361,14 +361,15 @@
 string MD5Hash::get_hex()
 {
 	uint8_t digest[16];
-	char buf[16*2];
+	char buf[16*2+1];
 
 	finish(digest);
 
 	for(int i=0; i<16; i++)
 		sprintf(buf + i*2, "%02X", digest[i]);
+	buf[sizeof(buf)-1] = '\0';
 	
-	return string(buf, sizeof(buf));
+	return string(buf);
 }
 
 CCL_NAMESPACE_END

Modified: branches/soc-2011-tomato/release/scripts/modules/bpy_extras/io_utils.py
===================================================================
--- branches/soc-2011-tomato/release/scripts/modules/bpy_extras/io_utils.py	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/release/scripts/modules/bpy_extras/io_utils.py	2011-12-06 09:27:18 UTC (rev 42458)
@@ -269,8 +269,6 @@
 
         return axis_forward, axis_up
 
-    change = False
-
     axis = getattr(operator, forward_attr), getattr(operator, up_attr)
     axis_new = validate(*axis)
 

Modified: branches/soc-2011-tomato/release/scripts/startup/bl_operators/object_randomize_transform.py
===================================================================
--- branches/soc-2011-tomato/release/scripts/startup/bl_operators/object_randomize_transform.py	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/release/scripts/startup/bl_operators/object_randomize_transform.py	2011-12-06 09:27:18 UTC (rev 42458)
@@ -62,7 +62,9 @@
             else:
                 org_sca_x, org_sca_y, org_sca_z = obj.scale
 
-            sca_x, sca_y, sca_z = uniform(-scale[0]+2, scale[0]), uniform(-scale[1]+2, scale[1]), uniform(-scale[2]+2, scale[2])
+            sca_x, sca_y, sca_z = (uniform(-scale[0] + 2.0, scale[0]),
+                                   uniform(-scale[1] + 2.0, scale[1]),
+                                   uniform(-scale[2] + 2.0, scale[2]))
 
             if scale_even:
                 aX = sca_x * org_sca_x
@@ -81,7 +83,9 @@
             uniform(0.0, 0.0), uniform(0.0, 0.0), uniform(0.0, 0.0)
 
 
-from bpy.props import IntProperty, BoolProperty, FloatProperty, FloatVectorProperty
+from bpy.props import (IntProperty,
+                       BoolProperty,
+                       FloatVectorProperty)
 
 
 class RandomizeLocRotSize(Operator):

Modified: branches/soc-2011-tomato/release/scripts/startup/bl_ui/properties_render.py
===================================================================
--- branches/soc-2011-tomato/release/scripts/startup/bl_ui/properties_render.py	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/release/scripts/startup/bl_ui/properties_render.py	2011-12-06 09:27:18 UTC (rev 42458)
@@ -453,7 +453,7 @@
 
         rd = context.scene.render
         image_settings = rd.image_settings
-        file_format = rd.image_settings.file_format
+        file_format = image_settings.file_format
 
         layout.prop(rd, "filepath", text="")
 
@@ -462,7 +462,7 @@
         flow.prop(rd, "use_placeholder")
         flow.prop(rd, "use_file_extension")
 
-        layout.template_image_settings(rd.image_settings)
+        layout.template_image_settings(image_settings)
 
         if file_format == 'QUICKTIME_CARBON':
             layout.operator("scene.render_data_set_quicktime_codec")

Modified: branches/soc-2011-tomato/release/scripts/startup/bl_ui/properties_texture.py
===================================================================
--- branches/soc-2011-tomato/release/scripts/startup/bl_ui/properties_texture.py	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/release/scripts/startup/bl_ui/properties_texture.py	2011-12-06 09:27:18 UTC (rev 42458)
@@ -166,7 +166,7 @@
             layout.template_preview(tex, parent=idblock, slot=slot)
         else:
             layout.template_preview(tex, slot=slot)
-            
+
         #Show Alpha Button for Brush Textures, see #29502
         if context.space_data.texture_context == 'BRUSH':
             layout.prop(tex, "use_preview_alpha")

Modified: branches/soc-2011-tomato/release/scripts/startup/bl_ui/space_clip.py
===================================================================
--- branches/soc-2011-tomato/release/scripts/startup/bl_ui/space_clip.py	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/release/scripts/startup/bl_ui/space_clip.py	2011-12-06 09:27:18 UTC (rev 42458)
@@ -120,7 +120,7 @@
             row.menu('CLIP_MT_tracking_settings_presets', text=label)
             row.operator("clip.tracking_settings_preset_add",
                          text="", icon='ZOOMIN')
-            props = row.operator("clip.track_color_preset_add",
+            props = row.operator("clip.tracking_settings_preset_add",
                                  text="", icon='ZOOMOUT')
             props.remove_active = True
 
@@ -161,7 +161,7 @@
 
     def draw(self, context):
         layout = self.layout
-        clip = context.space_data.clip
+        # clip = context.space_data.clip  # UNUSED
 
         row = layout.row(align=True)
 

Modified: branches/soc-2011-tomato/source/blender/editors/interface/interface_handlers.c
===================================================================
--- branches/soc-2011-tomato/source/blender/editors/screen/screendump.c	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/source/blender/editors/screen/screendump.c	2011-12-06 09:27:18 UTC (rev 42458)
@@ -218,8 +218,6 @@
 
 void SCREEN_OT_screenshot(wmOperatorType *ot)
 {
-	PropertyRNA *prop;
-
 	ot->name= "Save Screenshot"; /* weak: opname starting with 'save' makes filewindow give save-over */
 	ot->idname= "SCREEN_OT_screenshot";
 	
@@ -231,7 +229,7 @@
 	ot->flag= 0;
 	
 	WM_operator_properties_filesel(ot, FOLDERFILE|IMAGEFILE, FILE_SPECIAL, FILE_SAVE, WM_FILESEL_FILEPATH);
-	prop= RNA_def_boolean(ot->srna, "full", 1, "Full Screen", "");
+	RNA_def_boolean(ot->srna, "full", 1, "Full Screen", "");
 }
 
 /* *************** screenshot movie job ************************* */


Property changes on: branches/soc-2011-tomato/source/blender/editors/space_outliner
___________________________________________________________________
Modified: svn:mergeinfo
   - /branches/soc-2011-pepper/source/blender/editors/space_outliner:36831-38987
/trunk/blender/source/blender/editors/space_outliner:36831-42441
   + /branches/soc-2011-pepper/source/blender/editors/space_outliner:36831-38987
/trunk/blender/source/blender/editors/space_outliner:36831-42457

Modified: branches/soc-2011-tomato/source/blender/editors/space_view3d/drawobject.c

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list
--- branches/soc-2011-tomato/source/blender/editors/interface/interface_handlers.c	2011-12-06 09:23:35 UTC (rev 42457)
+++ branches/soc-2011-tomato/source/blender/editors/interface/interface_handlers.c	2011-12-06 09:27:18 UTC (rev 42458)
@@ -5241,9 +5241,10 @@
 
 	data->state= state;
 
-	if(state != BUTTON_STATE_EXIT) {
+	if(!ELEM(state, BUTTON_STATE_EXIT, BUTTON_STATE_HIGHLIGHT)) {
 		/* When objects for eg. are removed, running ui_check_but()
 		 * can access the removed data - so disable update on exit */
 		ui_check_but(but);
 	}
 
@@ -5241,9 +5241,10 @@
 		/* When objects for eg. are removed, running ui_check_but()
-		 * can access the removed data - so disable update on exit */
+		 * can access the removed data - so disable update on exit
+		 * or highlight */
 		ui_check_but(but);
 	}

Modified: branches/soc-2011-tomato/source/blender/editors/screen/screendump.c
===================================================================